@@ -1,6 +1,6 @@
 ;;; mh-xemacs.el --- XEmacs MH-E support
 
-;; Copyright (C) 2001, 02, 03, 2004 Free Software Foundation, Inc.
+;; Copyright (C) 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
 ;; Author: FSF and others (see below)
 ;; Maintainer: Bill Wohler <wohler@newt.com>
@@ -90,6 +90,16 @@ static char * file[] = {
 \"...#..#.#..#....#.\"};"
   "The image for the modeline logo.")
 
+(if (fboundp 'define-behavior-group)
+    (define-behavior 'mh
+      "Emacs interface to the MH mail system.
+MH is the Rand Mail Handler. Other implementations include nmh and GNU
+mailutils."
+      :short-doc "Emacs interface to the MH mail system"
+      :group 'internet
+      :commands
+      '(["Read Mail (MH-E)..." (mh-rmail t)])))
+
 (mh-do-in-xemacs
   (defvar mh-modeline-glyph
     (progn
